@@ -22,7 +22,7 @@
 
 # ----------------------------------------------------------------------------
 
-__version__ = '4.0.64'
+__version__ = '4.0.103'
 
 # ----------------------------------------------------------------------------
 
@@ -51,6 +51,7 @@ from ccxt.base.errors import ArgumentsRequired                        # noqa: F4
 from ccxt.base.errors import BadRequest                               # noqa: F401
 from ccxt.base.errors import BadSymbol                                # noqa: F401
 from ccxt.base.errors import MarginModeAlreadySet                     # noqa: F401
+from ccxt.base.errors import NoChange                                 # noqa: F401
 from ccxt.base.errors import BadResponse                              # noqa: F401
 from ccxt.base.errors import NullResponse                             # noqa: F401
 from ccxt.base.errors import InsufficientFunds                        # noqa: F401
@@ -105,7 +106,6 @@ from ccxt.bitstamp import bitstamp                                    # noqa: F4
 from ccxt.bitstamp1 import bitstamp1                                  # noqa: F401
 from ccxt.bittrex import bittrex                                      # noqa: F401
 from ccxt.bitvavo import bitvavo                                      # noqa: F401
-from ccxt.bkex import bkex                                            # noqa: F401
 from ccxt.bl3p import bl3p                                            # noqa: F401
 from ccxt.blockchaincom import blockchaincom                          # noqa: F401
 from ccxt.btcalpha import btcalpha                                    # noqa: F401
@@ -213,7 +213,6 @@ exchanges = [
     'bitstamp1',
     'bittrex',
     'bitvavo',
-    'bkex',
     'bl3p',
     'blockchaincom',
     'btcalpha',
