@@ -14,7 +14,10 @@ class ImplicitAPI:
     public_spot_get_market_candles = publicSpotGetMarketCandles = Entry('market/candles', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_market_depth = publicSpotGetMarketDepth = Entry('market/depth', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_market_spot_vip_level = publicSpotGetMarketSpotVipLevel = Entry('market/spot-vip-level', ['public', 'spot'], 'GET', {'cost': 2})
+    public_spot_get_market_merge_depth = publicSpotGetMarketMergeDepth = Entry('market/merge-depth', ['public', 'spot'], 'GET', {'cost': 1})
     public_spot_get_market_history_candles = publicSpotGetMarketHistoryCandles = Entry('market/history-candles', ['public', 'spot'], 'GET', {'cost': 1})
+    public_spot_get_public_loan_coininfos = publicSpotGetPublicLoanCoinInfos = Entry('public/loan/coinInfos', ['public', 'spot'], 'GET', {'cost': 2})
+    public_spot_get_public_loan_hour_interest = publicSpotGetPublicLoanHourInterest = Entry('public/loan/hour-interest', ['public', 'spot'], 'GET', {'cost': 2})
     public_mix_get_market_contracts = publicMixGetMarketContracts = Entry('market/contracts', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_depth = publicMixGetMarketDepth = Entry('market/depth', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_ticker = publicMixGetMarketTicker = Entry('market/ticker', ['public', 'mix'], 'GET', {'cost': 1})
@@ -35,6 +38,7 @@ class ImplicitAPI:
     public_mix_get_market_history_candles = publicMixGetMarketHistoryCandles = Entry('market/history-candles', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_history_index_candles = publicMixGetMarketHistoryIndexCandles = Entry('market/history-index-candles', ['public', 'mix'], 'GET', {'cost': 1})
     public_mix_get_market_history_mark_candles = publicMixGetMarketHistoryMarkCandles = Entry('market/history-mark-candles', ['public', 'mix'], 'GET', {'cost': 1})
+    public_mix_get_market_merge_depth = publicMixGetMarketMergeDepth = Entry('market/merge-depth', ['public', 'mix'], 'GET', {'cost': 1})
     public_margin_get_cross_public_interestrateandlimit = publicMarginGetCrossPublicInterestRateAndLimit = Entry('cross/public/interestRateAndLimit', ['public', 'margin'], 'GET', {'cost': 2})
     public_margin_get_isolated_public_interestrateandlimit = publicMarginGetIsolatedPublicInterestRateAndLimit = Entry('isolated/public/interestRateAndLimit', ['public', 'margin'], 'GET', {'cost': 2})
     public_margin_get_cross_public_tierdata = publicMarginGetCrossPublicTierData = Entry('cross/public/tierData', ['public', 'margin'], 'GET', {'cost': 2})
@@ -49,6 +53,11 @@ class ImplicitAPI:
     private_spot_get_account_transferrecords = privateSpotGetAccountTransferRecords = Entry('account/transferRecords', ['private', 'spot'], 'GET', {'cost': 1})
     private_spot_get_convert_currencies = privateSpotGetConvertCurrencies = Entry('convert/currencies', ['private', 'spot'], 'GET', {'cost': 2})
     private_spot_get_convert_convert_record = privateSpotGetConvertConvertRecord = Entry('convert/convert-record', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_loan_ongoing_orders = privateSpotGetLoanOngoingOrders = Entry('loan/ongoing-orders', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_loan_repay_history = privateSpotGetLoanRepayHistory = Entry('loan/repay-history', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_loan_revise_history = privateSpotGetLoanReviseHistory = Entry('loan/revise-history', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_loan_borrow_history = privateSpotGetLoanBorrowHistory = Entry('loan/borrow-history', ['private', 'spot'], 'GET', {'cost': 2})
+    private_spot_get_loan_debts = privateSpotGetLoanDebts = Entry('loan/debts', ['private', 'spot'], 'GET', {'cost': 2})
     private_spot_post_wallet_transfer = privateSpotPostWalletTransfer = Entry('wallet/transfer', ['private', 'spot'], 'POST', {'cost': 4})
     private_spot_post_wallet_transfer_v2 = privateSpotPostWalletTransferV2 = Entry('wallet/transfer-v2', ['private', 'spot'], 'POST', {'cost': 4})
     private_spot_post_wallet_subtransfer = privateSpotPostWalletSubTransfer = Entry('wallet/subTransfer', ['private', 'spot'], 'POST', {'cost': 10})
@@ -77,6 +86,9 @@ class ImplicitAPI:
     private_spot_post_plan_batchcancelplan = privateSpotPostPlanBatchCancelPlan = Entry('plan/batchCancelPlan', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_convert_quoted_price = privateSpotPostConvertQuotedPrice = Entry('convert/quoted-price', ['private', 'spot'], 'POST', {'cost': 4})
     private_spot_post_convert_trade = privateSpotPostConvertTrade = Entry('convert/trade', ['private', 'spot'], 'POST', {'cost': 4})
+    private_spot_post_loan_borrow = privateSpotPostLoanBorrow = Entry('loan/borrow', ['private', 'spot'], 'POST', {'cost': 2})
+    private_spot_post_loan_repay = privateSpotPostLoanRepay = Entry('loan/repay', ['private', 'spot'], 'POST', {'cost': 2})
+    private_spot_post_loan_revise_pledge = privateSpotPostLoanRevisePledge = Entry('loan/revise-pledge', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_order_ordercurrentlist = privateSpotPostTraceOrderOrderCurrentList = Entry('trace/order/orderCurrentList', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_order_orderhistorylist = privateSpotPostTraceOrderOrderHistoryList = Entry('trace/order/orderHistoryList', ['private', 'spot'], 'POST', {'cost': 2})
     private_spot_post_trace_order_closetrackingorder = privateSpotPostTraceOrderCloseTrackingOrder = Entry('trace/order/closeTrackingOrder', ['private', 'spot'], 'POST', {'cost': 2})
@@ -192,6 +204,9 @@ class ImplicitAPI:
     private_broker_get_account_sub_email = privateBrokerGetAccountSubEmail = Entry('account/sub-email', ['private', 'broker'], 'GET', {'cost': 20})
     private_broker_get_account_sub_spot_assets = privateBrokerGetAccountSubSpotAssets = Entry('account/sub-spot-assets', ['private', 'broker'], 'GET', {'cost': 2})
     private_broker_get_account_sub_future_assets = privateBrokerGetAccountSubFutureAssets = Entry('account/sub-future-assets', ['private', 'broker'], 'GET', {'cost': 2})
+    private_broker_get_account_subaccount_transfer = privateBrokerGetAccountSubaccountTransfer = Entry('account/subaccount-transfer', ['private', 'broker'], 'GET', {'cost': 1})
+    private_broker_get_account_subaccount_deposit = privateBrokerGetAccountSubaccountDeposit = Entry('account/subaccount-deposit', ['private', 'broker'], 'GET', {'cost': 1})
+    private_broker_get_account_subaccount_withdrawal = privateBrokerGetAccountSubaccountWithdrawal = Entry('account/subaccount-withdrawal', ['private', 'broker'], 'GET', {'cost': 1})
     private_broker_get_account_sub_api_list = privateBrokerGetAccountSubApiList = Entry('account/sub-api-list', ['private', 'broker'], 'GET', {'cost': 2})
     private_broker_post_account_sub_create = privateBrokerPostAccountSubCreate = Entry('account/sub-create', ['private', 'broker'], 'POST', {'cost': 20})
     private_broker_post_account_sub_modify = privateBrokerPostAccountSubModify = Entry('account/sub-modify', ['private', 'broker'], 'POST', {'cost': 20})
