@@ -81,27 +81,30 @@ class ImplicitAPI:
     public_get_derivatives_v3_public_recent_trade = publicGetDerivativesV3PublicRecentTrade = Entry('derivatives/v3/public/recent-trade', 'public', 'GET', {'cost': 1})
     public_get_derivatives_v3_public_open_interest = publicGetDerivativesV3PublicOpenInterest = Entry('derivatives/v3/public/open-interest', 'public', 'GET', {'cost': 1})
     public_get_derivatives_v3_public_insurance = publicGetDerivativesV3PublicInsurance = Entry('derivatives/v3/public/insurance', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_time = publicGetV5MarketTime = Entry('v5/market/time', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_kline = publicGetV5MarketKline = Entry('v5/market/kline', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_mark_price_kline = publicGetV5MarketMarkPriceKline = Entry('v5/market/mark-price-kline', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_index_price_kline = publicGetV5MarketIndexPriceKline = Entry('v5/market/index-price-kline', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_premium_index_price_kline = publicGetV5MarketPremiumIndexPriceKline = Entry('v5/market/premium-index-price-kline', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_instruments_info = publicGetV5MarketInstrumentsInfo = Entry('v5/market/instruments-info', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_orderbook = publicGetV5MarketOrderbook = Entry('v5/market/orderbook', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_tickers = publicGetV5MarketTickers = Entry('v5/market/tickers', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_funding_history = publicGetV5MarketFundingHistory = Entry('v5/market/funding/history', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_recent_trade = publicGetV5MarketRecentTrade = Entry('v5/market/recent-trade', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_open_interest = publicGetV5MarketOpenInterest = Entry('v5/market/open-interest', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_historical_volatility = publicGetV5MarketHistoricalVolatility = Entry('v5/market/historical-volatility', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_insurance = publicGetV5MarketInsurance = Entry('v5/market/insurance', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_risk_limit = publicGetV5MarketRiskLimit = Entry('v5/market/risk-limit', 'public', 'GET', {'cost': 1})
-    public_get_v5_market_delivery_price = publicGetV5MarketDeliveryPrice = Entry('v5/market/delivery-price', 'public', 'GET', {'cost': 1})
-    public_get_v5_spot_lever_token_info = publicGetV5SpotLeverTokenInfo = Entry('v5/spot-lever-token/info', 'public', 'GET', {'cost': 1})
-    public_get_v5_spot_lever_token_reference = publicGetV5SpotLeverTokenReference = Entry('v5/spot-lever-token/reference', 'public', 'GET', {'cost': 1})
-    public_get_v5_announcements_index = publicGetV5AnnouncementsIndex = Entry('v5/announcements/index', 'public', 'GET', {'cost': 1})
-    public_get_v5_spot_cross_margin_trade_pledge_token = publicGetV5SpotCrossMarginTradePledgeToken = Entry('v5/spot-cross-margin-trade/pledge-token', 'public', 'GET', {'cost': 1})
-    public_get_v5_spot_cross_margin_trade_borrow_token = publicGetV5SpotCrossMarginTradeBorrowToken = Entry('v5/spot-cross-margin-trade/borrow-token', 'public', 'GET', {'cost': 1})
-    public_get_v5_ins_loan_ensure_tokens_convert = publicGetV5InsLoanEnsureTokensConvert = Entry('v5/ins-loan/ensure-tokens-convert', 'public', 'GET', {'cost': 1})
+    public_get_v5_announcements_index = publicGetV5AnnouncementsIndex = Entry('v5/announcements/index', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_time = publicGetV5MarketTime = Entry('v5/market/time', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_kline = publicGetV5MarketKline = Entry('v5/market/kline', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_mark_price_kline = publicGetV5MarketMarkPriceKline = Entry('v5/market/mark-price-kline', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_index_price_kline = publicGetV5MarketIndexPriceKline = Entry('v5/market/index-price-kline', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_premium_index_price_kline = publicGetV5MarketPremiumIndexPriceKline = Entry('v5/market/premium-index-price-kline', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_instruments_info = publicGetV5MarketInstrumentsInfo = Entry('v5/market/instruments-info', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_orderbook = publicGetV5MarketOrderbook = Entry('v5/market/orderbook', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_tickers = publicGetV5MarketTickers = Entry('v5/market/tickers', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_funding_history = publicGetV5MarketFundingHistory = Entry('v5/market/funding/history', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_recent_trade = publicGetV5MarketRecentTrade = Entry('v5/market/recent-trade', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_open_interest = publicGetV5MarketOpenInterest = Entry('v5/market/open-interest', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_historical_volatility = publicGetV5MarketHistoricalVolatility = Entry('v5/market/historical-volatility', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_insurance = publicGetV5MarketInsurance = Entry('v5/market/insurance', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_risk_limit = publicGetV5MarketRiskLimit = Entry('v5/market/risk-limit', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_market_delivery_price = publicGetV5MarketDeliveryPrice = Entry('v5/market/delivery-price', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_spot_lever_token_info = publicGetV5SpotLeverTokenInfo = Entry('v5/spot-lever-token/info', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_spot_lever_token_reference = publicGetV5SpotLeverTokenReference = Entry('v5/spot-lever-token/reference', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_spot_margin_trade_data = publicGetV5SpotMarginTradeData = Entry('v5/spot-margin-trade/data', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_spot_cross_margin_trade_data = publicGetV5SpotCrossMarginTradeData = Entry('v5/spot-cross-margin-trade/data', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_spot_cross_margin_trade_pledge_token = publicGetV5SpotCrossMarginTradePledgeToken = Entry('v5/spot-cross-margin-trade/pledge-token', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_spot_cross_margin_trade_borrow_token = publicGetV5SpotCrossMarginTradeBorrowToken = Entry('v5/spot-cross-margin-trade/borrow-token', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_ins_loan_product_infos = publicGetV5InsLoanProductInfos = Entry('v5/ins-loan/product-infos', 'public', 'GET', {'cost': 2.5})
+    public_get_v5_ins_loan_ensure_tokens_convert = publicGetV5InsLoanEnsureTokensConvert = Entry('v5/ins-loan/ensure-tokens-convert', 'public', 'GET', {'cost': 2.5})
     private_get_v2_private_order_list = privateGetV2PrivateOrderList = Entry('v2/private/order/list', 'private', 'GET', {'cost': 5})
     private_get_v2_private_order = privateGetV2PrivateOrder = Entry('v2/private/order', 'private', 'GET', {'cost': 5})
     private_get_v2_private_stop_order_list = privateGetV2PrivateStopOrderList = Entry('v2/private/stop-order/list', 'private', 'GET', {'cost': 5})
@@ -210,57 +213,63 @@ class ImplicitAPI:
     private_get_asset_v3_public_deposit_allowed_deposit_list_query = privateGetAssetV3PublicDepositAllowedDepositListQuery = Entry('asset/v3/public/deposit/allowed-deposit-list/query', 'private', 'GET', {'cost': 0.17})
     private_get_asset_v3_private_deposit_record_query = privateGetAssetV3PrivateDepositRecordQuery = Entry('asset/v3/private/deposit/record/query', 'private', 'GET', {'cost': 0.17})
     private_get_asset_v3_private_withdraw_record_query = privateGetAssetV3PrivateWithdrawRecordQuery = Entry('asset/v3/private/withdraw/record/query', 'private', 'GET', {'cost': 0.17})
-    private_get_v5_order_history = privateGetV5OrderHistory = Entry('v5/order/history', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_order_realtime = privateGetV5OrderRealtime = Entry('v5/order/realtime', 'private', 'GET', {'cost': 5})
+    private_get_v5_order_history = privateGetV5OrderHistory = Entry('v5/order/history', 'private', 'GET', {'cost': 5})
     private_get_v5_order_spot_borrow_check = privateGetV5OrderSpotBorrowCheck = Entry('v5/order/spot-borrow-check', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_order_realtime = privateGetV5OrderRealtime = Entry('v5/order/realtime', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_position_list = privateGetV5PositionList = Entry('v5/position/list', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_position_switch_mode = privateGetV5PositionSwitchMode = Entry('v5/position/switch-mode', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_execution_list = privateGetV5ExecutionList = Entry('v5/execution/list', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_position_closed_pnl = privateGetV5PositionClosedPnl = Entry('v5/position/closed-pnl', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_account_wallet_balance = privateGetV5AccountWalletBalance = Entry('v5/account/wallet-balance', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_position_list = privateGetV5PositionList = Entry('v5/position/list', 'private', 'GET', {'cost': 5})
+    private_get_v5_execution_list = privateGetV5ExecutionList = Entry('v5/execution/list', 'private', 'GET', {'cost': 5})
+    private_get_v5_position_closed_pnl = privateGetV5PositionClosedPnl = Entry('v5/position/closed-pnl', 'private', 'GET', {'cost': 5})
+    private_get_v5_pre_upgrade_order_history = privateGetV5PreUpgradeOrderHistory = Entry('v5/pre-upgrade/order/history', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_pre_upgrade_execution_list = privateGetV5PreUpgradeExecutionList = Entry('v5/pre-upgrade/execution/list', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_pre_upgrade_position_closed_pnl = privateGetV5PreUpgradePositionClosedPnl = Entry('v5/pre-upgrade/position/closed-pnl', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_pre_upgrade_account_transaction_log = privateGetV5PreUpgradeAccountTransactionLog = Entry('v5/pre-upgrade/account/transaction-log', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_pre_upgrade_asset_delivery_record = privateGetV5PreUpgradeAssetDeliveryRecord = Entry('v5/pre-upgrade/asset/delivery-record', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_pre_upgrade_asset_settlement_record = privateGetV5PreUpgradeAssetSettlementRecord = Entry('v5/pre-upgrade/asset/settlement-record', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_account_wallet_balance = privateGetV5AccountWalletBalance = Entry('v5/account/wallet-balance', 'private', 'GET', {'cost': 5})
     private_get_v5_account_borrow_history = privateGetV5AccountBorrowHistory = Entry('v5/account/borrow-history', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_account_set_collateral_switch = privateGetV5AccountSetCollateralSwitch = Entry('v5/account/set-collateral-switch', 'private', 'GET', {'cost': 2.5})
     private_get_v5_account_collateral_info = privateGetV5AccountCollateralInfo = Entry('v5/account/collateral-info', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_account_mmp_state = privateGetV5AccountMmpState = Entry('v5/account/mmp-state', 'private', 'GET', {'cost': 2.5})
     private_get_v5_asset_coin_greeks = privateGetV5AssetCoinGreeks = Entry('v5/asset/coin-greeks', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_account_fee_rate = privateGetV5AccountFeeRate = Entry('v5/account/fee-rate', 'private', 'GET', {'cost': 5})
     private_get_v5_account_info = privateGetV5AccountInfo = Entry('v5/account/info', 'private', 'GET', {'cost': 2.5})
     private_get_v5_account_transaction_log = privateGetV5AccountTransactionLog = Entry('v5/account/transaction-log', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_account_fee_rate = privateGetV5AccountFeeRate = Entry('v5/account/fee-rate', 'private', 'GET', {'cost': 1})
-    private_get_v5_asset_exchange_order_record = privateGetV5AssetExchangeOrderRecord = Entry('v5/asset/exchange/order-record', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_account_mmp_state = privateGetV5AccountMmpState = Entry('v5/account/mmp-state', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_asset_exchange_order_record = privateGetV5AssetExchangeOrderRecord = Entry('v5/asset/exchange/order-record', 'private', 'GET', {'cost': 5})
     private_get_v5_asset_delivery_record = privateGetV5AssetDeliveryRecord = Entry('v5/asset/delivery-record', 'private', 'GET', {'cost': 2.5})
     private_get_v5_asset_settlement_record = privateGetV5AssetSettlementRecord = Entry('v5/asset/settlement-record', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_asset_info = privateGetV5AssetTransferQueryAssetInfo = Entry('v5/asset/transfer/query-asset-info', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_account_coin_balance = privateGetV5AssetTransferQueryAccountCoinBalance = Entry('v5/asset/transfer/query-account-coin-balance', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_transfer_coin_list = privateGetV5AssetTransferQueryTransferCoinList = Entry('v5/asset/transfer/query-transfer-coin-list', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_inter_transfer_list = privateGetV5AssetTransferQueryInterTransferList = Entry('v5/asset/transfer/query-inter-transfer-list', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_sub_member_list = privateGetV5AssetTransferQuerySubMemberList = Entry('v5/asset/transfer/query-sub-member-list', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_universal_transfer_list = privateGetV5AssetTransferQueryUniversalTransferList = Entry('v5/asset/transfer/query-universal-transfer-list', 'private', 'GET', {'cost': 1})
+    private_get_v5_asset_transfer_query_asset_info = privateGetV5AssetTransferQueryAssetInfo = Entry('v5/asset/transfer/query-asset-info', 'private', 'GET', {'cost': 50})
+    private_get_v5_asset_transfer_query_account_coins_balance = privateGetV5AssetTransferQueryAccountCoinsBalance = Entry('v5/asset/transfer/query-account-coins-balance', 'private', 'GET', {'cost': 25})
+    private_get_v5_asset_transfer_query_account_coin_balance = privateGetV5AssetTransferQueryAccountCoinBalance = Entry('v5/asset/transfer/query-account-coin-balance', 'private', 'GET', {'cost': 50})
+    private_get_v5_asset_transfer_query_transfer_coin_list = privateGetV5AssetTransferQueryTransferCoinList = Entry('v5/asset/transfer/query-transfer-coin-list', 'private', 'GET', {'cost': 50})
+    private_get_v5_asset_transfer_query_inter_transfer_list = privateGetV5AssetTransferQueryInterTransferList = Entry('v5/asset/transfer/query-inter-transfer-list', 'private', 'GET', {'cost': 50})
+    private_get_v5_asset_transfer_query_sub_member_list = privateGetV5AssetTransferQuerySubMemberList = Entry('v5/asset/transfer/query-sub-member-list', 'private', 'GET', {'cost': 50})
+    private_get_v5_asset_transfer_query_universal_transfer_list = privateGetV5AssetTransferQueryUniversalTransferList = Entry('v5/asset/transfer/query-universal-transfer-list', 'private', 'GET', {'cost': 25})
     private_get_v5_asset_deposit_query_allowed_list = privateGetV5AssetDepositQueryAllowedList = Entry('v5/asset/deposit/query-allowed-list', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_deposit_query_record = privateGetV5AssetDepositQueryRecord = Entry('v5/asset/deposit/query-record', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_deposit_query_sub_member_record = privateGetV5AssetDepositQuerySubMemberRecord = Entry('v5/asset/deposit/query-sub-member-record', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_deposit_query_address = privateGetV5AssetDepositQueryAddress = Entry('v5/asset/deposit/query-address', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_deposit_query_sub_member_address = privateGetV5AssetDepositQuerySubMemberAddress = Entry('v5/asset/deposit/query-sub-member-address', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_asset_deposit_query_record = privateGetV5AssetDepositQueryRecord = Entry('v5/asset/deposit/query-record', 'private', 'GET', {'cost': 10})
+    private_get_v5_asset_deposit_query_sub_member_record = privateGetV5AssetDepositQuerySubMemberRecord = Entry('v5/asset/deposit/query-sub-member-record', 'private', 'GET', {'cost': 10})
     private_get_v5_asset_deposit_query_internal_record = privateGetV5AssetDepositQueryInternalRecord = Entry('v5/asset/deposit/query-internal-record', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_coin_query_info = privateGetV5AssetCoinQueryInfo = Entry('v5/asset/coin/query-info', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_withdraw_query_record = privateGetV5AssetWithdrawQueryRecord = Entry('v5/asset/withdraw/query-record', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_asset_deposit_query_address = privateGetV5AssetDepositQueryAddress = Entry('v5/asset/deposit/query-address', 'private', 'GET', {'cost': 10})
+    private_get_v5_asset_deposit_query_sub_member_address = privateGetV5AssetDepositQuerySubMemberAddress = Entry('v5/asset/deposit/query-sub-member-address', 'private', 'GET', {'cost': 10})
+    private_get_v5_asset_coin_query_info = privateGetV5AssetCoinQueryInfo = Entry('v5/asset/coin/query-info', 'private', 'GET', {'cost': 25})
+    private_get_v5_asset_withdraw_query_record = privateGetV5AssetWithdrawQueryRecord = Entry('v5/asset/withdraw/query-record', 'private', 'GET', {'cost': 10})
     private_get_v5_asset_withdraw_withdrawable_amount = privateGetV5AssetWithdrawWithdrawableAmount = Entry('v5/asset/withdraw/withdrawable-amount', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_asset_transfer_query_account_coins_balance = privateGetV5AssetTransferQueryAccountCoinsBalance = Entry('v5/asset/transfer/query-account-coins-balance', 'private', 'GET', {'cost': 2.5})
-    private_get_v5_user_query_sub_members = privateGetV5UserQuerySubMembers = Entry('v5/user/query-sub-members', 'private', 'GET', {'cost': 10})
-    private_get_v5_user_query_api = privateGetV5UserQueryApi = Entry('v5/user/query-api', 'private', 'GET', {'cost': 10})
-    private_get_v5_user_get_member_type = privateGetV5UserGetMemberType = Entry('v5/user/get-member-type', 'private', 'GET', {'cost': 1})
-    private_get_v5_user_aff_customer_info = privateGetV5UserAffCustomerInfo = Entry('v5/user/aff-customer-info', 'private', 'GET', {'cost': 10})
-    private_get_v5_customer_info = privateGetV5CustomerInfo = Entry('v5/customer/info', 'private', 'GET', {'cost': 10})
+    private_get_v5_user_query_sub_members = privateGetV5UserQuerySubMembers = Entry('v5/user/query-sub-members', 'private', 'GET', {'cost': 5})
+    private_get_v5_user_query_api = privateGetV5UserQueryApi = Entry('v5/user/query-api', 'private', 'GET', {'cost': 5})
+    private_get_v5_user_get_member_type = privateGetV5UserGetMemberType = Entry('v5/user/get-member-type', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_user_aff_customer_info = privateGetV5UserAffCustomerInfo = Entry('v5/user/aff-customer-info', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_spot_lever_token_order_record = privateGetV5SpotLeverTokenOrderRecord = Entry('v5/spot-lever-token/order-record', 'private', 'GET', {'cost': 1})
+    private_get_v5_spot_margin_trade_state = privateGetV5SpotMarginTradeState = Entry('v5/spot-margin-trade/state', 'private', 'GET', {'cost': 2.5})
     private_get_v5_spot_cross_margin_trade_loan_info = privateGetV5SpotCrossMarginTradeLoanInfo = Entry('v5/spot-cross-margin-trade/loan-info', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_account = privateGetV5SpotCrossMarginTradeAccount = Entry('v5/spot-cross-margin-trade/account', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_orders = privateGetV5SpotCrossMarginTradeOrders = Entry('v5/spot-cross-margin-trade/orders', 'private', 'GET', {'cost': 1})
     private_get_v5_spot_cross_margin_trade_repay_history = privateGetV5SpotCrossMarginTradeRepayHistory = Entry('v5/spot-cross-margin-trade/repay-history', 'private', 'GET', {'cost': 1})
-    private_get_v5_ins_loan_ltv_convert = privateGetV5InsLoanLtvConvert = Entry('v5/ins-loan/ltv-convert', 'private', 'GET', {'cost': 1})
-    private_get_v5_broker_earning_record = privateGetV5BrokerEarningRecord = Entry('v5/broker/earning-record', 'private', 'GET', {'cost': 1})
-    private_get_v5_pre_upgrade_order_history = privateGetV5PreUpgradeOrderHistory = Entry('v5/pre-upgrade/order/history', 'private', 'GET', {'cost': 1})
-    private_get_v5_pre_upgrade_execution_list = privateGetV5PreUpgradeExecutionList = Entry('v5/pre-upgrade/execution/list', 'private', 'GET', {'cost': 1})
-    private_get_v5_pre_upgrade_position_closed_pnl = privateGetV5PreUpgradePositionClosedPnl = Entry('v5/pre-upgrade/position/closed-pnl', 'private', 'GET', {'cost': 1})
-    private_get_v5_pre_upgrade_account_transaction_log = privateGetV5PreUpgradeAccountTransactionLog = Entry('v5/pre-upgrade/account/transaction-log', 'private', 'GET', {'cost': 1})
-    private_get_v5_pre_upgrade_asset_delivery_record = privateGetV5PreUpgradeAssetDeliveryRecord = Entry('v5/pre-upgrade/asset/delivery-record', 'private', 'GET', {'cost': 1})
-    private_get_v5_pre_upgrade_asset_settlement_record = privateGetV5PreUpgradeAssetSettlementRecord = Entry('v5/pre-upgrade/asset/settlement-record', 'private', 'GET', {'cost': 1})
+    private_get_v5_ins_loan_loan_order = privateGetV5InsLoanLoanOrder = Entry('v5/ins-loan/loan-order', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_ins_loan_repaid_history = privateGetV5InsLoanRepaidHistory = Entry('v5/ins-loan/repaid-history', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_ins_loan_ltv_convert = privateGetV5InsLoanLtvConvert = Entry('v5/ins-loan/ltv-convert', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_lending_info = privateGetV5LendingInfo = Entry('v5/lending/info', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_lending_history_order = privateGetV5LendingHistoryOrder = Entry('v5/lending/history-order', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_lending_account = privateGetV5LendingAccount = Entry('v5/lending/account', 'private', 'GET', {'cost': 2.5})
+    private_get_v5_broker_earning_record = privateGetV5BrokerEarningRecord = Entry('v5/broker/earning-record', 'private', 'GET', {'cost': 2.5})
     private_post_v2_private_order_create = privatePostV2PrivateOrderCreate = Entry('v2/private/order/create', 'private', 'POST', {'cost': 30})
     private_post_v2_private_order_cancel = privatePostV2PrivateOrderCancel = Entry('v2/private/order/cancel', 'private', 'POST', {'cost': 30})
     private_post_v2_private_order_cancelall = privatePostV2PrivateOrderCancelAll = Entry('v2/private/order/cancelAll', 'private', 'POST', {'cost': 300})
@@ -401,34 +410,32 @@ class ImplicitAPI:
     private_post_fht_compliance_tax_v3_private_create = privatePostFhtComplianceTaxV3PrivateCreate = Entry('fht/compliance/tax/v3/private/create', 'private', 'POST', {'cost': 50})
     private_post_fht_compliance_tax_v3_private_status = privatePostFhtComplianceTaxV3PrivateStatus = Entry('fht/compliance/tax/v3/private/status', 'private', 'POST', {'cost': 50})
     private_post_fht_compliance_tax_v3_private_url = privatePostFhtComplianceTaxV3PrivateUrl = Entry('fht/compliance/tax/v3/private/url', 'private', 'POST', {'cost': 50})
-    private_post_v5_order_create = privatePostV5OrderCreate = Entry('v5/order/create', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_order_amend = privatePostV5OrderAmend = Entry('v5/order/amend', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_order_cancel = privatePostV5OrderCancel = Entry('v5/order/cancel', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_order_cancel_all = privatePostV5OrderCancelAll = Entry('v5/order/cancel-all', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_order_create_batch = privatePostV5OrderCreateBatch = Entry('v5/order/create-batch', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_order_amend_batch = privatePostV5OrderAmendBatch = Entry('v5/order/amend-batch', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_order_cancel_batch = privatePostV5OrderCancelBatch = Entry('v5/order/cancel-batch', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_order_create = privatePostV5OrderCreate = Entry('v5/order/create', 'private', 'POST', {'cost': 5})
+    private_post_v5_order_amend = privatePostV5OrderAmend = Entry('v5/order/amend', 'private', 'POST', {'cost': 5})
+    private_post_v5_order_cancel = privatePostV5OrderCancel = Entry('v5/order/cancel', 'private', 'POST', {'cost': 5})
+    private_post_v5_order_cancel_all = privatePostV5OrderCancelAll = Entry('v5/order/cancel-all', 'private', 'POST', {'cost': 5})
+    private_post_v5_order_create_batch = privatePostV5OrderCreateBatch = Entry('v5/order/create-batch', 'private', 'POST', {'cost': 5})
+    private_post_v5_order_amend_batch = privatePostV5OrderAmendBatch = Entry('v5/order/amend-batch', 'private', 'POST', {'cost': 5})
+    private_post_v5_order_cancel_batch = privatePostV5OrderCancelBatch = Entry('v5/order/cancel-batch', 'private', 'POST', {'cost': 5})
     private_post_v5_order_disconnected_cancel_all = privatePostV5OrderDisconnectedCancelAll = Entry('v5/order/disconnected-cancel-all', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_position_set_leverage = privatePostV5PositionSetLeverage = Entry('v5/position/set-leverage', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_position_set_tpsl_mode = privatePostV5PositionSetTpslMode = Entry('v5/position/set-tpsl-mode', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_position_set_risk_limit = privatePostV5PositionSetRiskLimit = Entry('v5/position/set-risk-limit', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_position_trading_stop = privatePostV5PositionTradingStop = Entry('v5/position/trading-stop', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_position_set_leverage = privatePostV5PositionSetLeverage = Entry('v5/position/set-leverage', 'private', 'POST', {'cost': 5})
     private_post_v5_position_switch_isolated = privatePostV5PositionSwitchIsolated = Entry('v5/position/switch-isolated', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_position_set_tpsl_mode = privatePostV5PositionSetTpslMode = Entry('v5/position/set-tpsl-mode', 'private', 'POST', {'cost': 5})
     private_post_v5_position_switch_mode = privatePostV5PositionSwitchMode = Entry('v5/position/switch-mode', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_position_set_risk_limit = privatePostV5PositionSetRiskLimit = Entry('v5/position/set-risk-limit', 'private', 'POST', {'cost': 5})
+    private_post_v5_position_trading_stop = privatePostV5PositionTradingStop = Entry('v5/position/trading-stop', 'private', 'POST', {'cost': 5})
     private_post_v5_position_set_auto_add_margin = privatePostV5PositionSetAutoAddMargin = Entry('v5/position/set-auto-add-margin', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_position_add_margin = privatePostV5PositionAddMargin = Entry('v5/position/add-margin', 'private', 'POST', {'cost': 2.5})
     private_post_v5_account_upgrade_to_uta = privatePostV5AccountUpgradeToUta = Entry('v5/account/upgrade-to-uta', 'private', 'POST', {'cost': 2.5})
     private_post_v5_account_set_margin_mode = privatePostV5AccountSetMarginMode = Entry('v5/account/set-margin-mode', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_asset_transfer_inter_transfer = privatePostV5AssetTransferInterTransfer = Entry('v5/asset/transfer/inter-transfer', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_asset_transfer_save_transfer_sub_member = privatePostV5AssetTransferSaveTransferSubMember = Entry('v5/asset/transfer/save-transfer-sub-member', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_asset_transfer_universal_transfer = privatePostV5AssetTransferUniversalTransfer = Entry('v5/asset/transfer/universal-transfer', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_account_mmp_modify = privatePostV5AccountMmpModify = Entry('v5/account/mmp-modify', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_account_mmp_reset = privatePostV5AccountMmpReset = Entry('v5/account/mmp-reset', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_asset_transfer_inter_transfer = privatePostV5AssetTransferInterTransfer = Entry('v5/asset/transfer/inter-transfer', 'private', 'POST', {'cost': 150})
+    private_post_v5_asset_transfer_save_transfer_sub_member = privatePostV5AssetTransferSaveTransferSubMember = Entry('v5/asset/transfer/save-transfer-sub-member', 'private', 'POST', {'cost': 150})
+    private_post_v5_asset_transfer_universal_transfer = privatePostV5AssetTransferUniversalTransfer = Entry('v5/asset/transfer/universal-transfer', 'private', 'POST', {'cost': 10})
     private_post_v5_asset_deposit_deposit_to_account = privatePostV5AssetDepositDepositToAccount = Entry('v5/asset/deposit/deposit-to-account', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_asset_withdraw_create = privatePostV5AssetWithdrawCreate = Entry('v5/asset/withdraw/create', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_asset_withdraw_cancel = privatePostV5AssetWithdrawCancel = Entry('v5/asset/withdraw/cancel', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_spot_lever_token_purchase = privatePostV5SpotLeverTokenPurchase = Entry('v5/spot-lever-token/purchase', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_spot_lever_token_redeem = privatePostV5SpotLeverTokenRedeem = Entry('v5/spot-lever-token/redeem', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_spot_lever_token_order_record = privatePostV5SpotLeverTokenOrderRecord = Entry('v5/spot-lever-token/order-record', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_spot_margin_trade_switch_mode = privatePostV5SpotMarginTradeSwitchMode = Entry('v5/spot-margin-trade/switch-mode', 'private', 'POST', {'cost': 2.5})
-    private_post_v5_spot_margin_trade_set_leverage = privatePostV5SpotMarginTradeSetLeverage = Entry('v5/spot-margin-trade/set-leverage', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_asset_withdraw_create = privatePostV5AssetWithdrawCreate = Entry('v5/asset/withdraw/create', 'private', 'POST', {'cost': 300})
+    private_post_v5_asset_withdraw_cancel = privatePostV5AssetWithdrawCancel = Entry('v5/asset/withdraw/cancel', 'private', 'POST', {'cost': 50})
     private_post_v5_user_create_sub_member = privatePostV5UserCreateSubMember = Entry('v5/user/create-sub-member', 'private', 'POST', {'cost': 10})
     private_post_v5_user_create_sub_api = privatePostV5UserCreateSubApi = Entry('v5/user/create-sub-api', 'private', 'POST', {'cost': 10})
     private_post_v5_user_frozen_sub_member = privatePostV5UserFrozenSubMember = Entry('v5/user/frozen-sub-member', 'private', 'POST', {'cost': 10})
@@ -436,9 +443,15 @@ class ImplicitAPI:
     private_post_v5_user_update_sub_api = privatePostV5UserUpdateSubApi = Entry('v5/user/update-sub-api', 'private', 'POST', {'cost': 10})
     private_post_v5_user_delete_api = privatePostV5UserDeleteApi = Entry('v5/user/delete-api', 'private', 'POST', {'cost': 10})
     private_post_v5_user_delete_sub_api = privatePostV5UserDeleteSubApi = Entry('v5/user/delete-sub-api', 'private', 'POST', {'cost': 10})
+    private_post_v5_spot_lever_token_purchase = privatePostV5SpotLeverTokenPurchase = Entry('v5/spot-lever-token/purchase', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_spot_lever_token_redeem = privatePostV5SpotLeverTokenRedeem = Entry('v5/spot-lever-token/redeem', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_spot_margin_trade_switch_mode = privatePostV5SpotMarginTradeSwitchMode = Entry('v5/spot-margin-trade/switch-mode', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_spot_margin_trade_set_leverage = privatePostV5SpotMarginTradeSetLeverage = Entry('v5/spot-margin-trade/set-leverage', 'private', 'POST', {'cost': 2.5})
     private_post_v5_spot_cross_margin_trade_loan = privatePostV5SpotCrossMarginTradeLoan = Entry('v5/spot-cross-margin-trade/loan', 'private', 'POST', {'cost': 2.5})
     private_post_v5_spot_cross_margin_trade_repay = privatePostV5SpotCrossMarginTradeRepay = Entry('v5/spot-cross-margin-trade/repay', 'private', 'POST', {'cost': 2.5})
     private_post_v5_spot_cross_margin_trade_switch = privatePostV5SpotCrossMarginTradeSwitch = Entry('v5/spot-cross-margin-trade/switch', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_lending_purchase = privatePostV5LendingPurchase = Entry('v5/lending/purchase', 'private', 'POST', {'cost': 2.5})
+    private_post_v5_lending_redeem = privatePostV5LendingRedeem = Entry('v5/lending/redeem', 'private', 'POST', {'cost': 2.5})
     private_delete_spot_v1_order = privateDeleteSpotV1Order = Entry('spot/v1/order', 'private', 'DELETE', {'cost': 2.5})
     private_delete_spot_v1_order_fast = privateDeleteSpotV1OrderFast = Entry('spot/v1/order/fast', 'private', 'DELETE', {'cost': 2.5})
     private_delete_spot_order_batch_cancel = privateDeleteSpotOrderBatchCancel = Entry('spot/order/batch-cancel', 'private', 'DELETE', {'cost': 2.5})
