@@ -195,6 +195,7 @@ class ImplicitAPI:
     spot_private_post_v1_subuser_transfer = spotPrivatePostV1SubuserTransfer = Entry('v1/subuser/transfer', ['spot', 'private'], 'POST', {'cost': 10})
     spot_private_post_v1_order_orders_place = spotPrivatePostV1OrderOrdersPlace = Entry('v1/order/orders/place', ['spot', 'private'], 'POST', {'cost': 0.2})
     spot_private_post_v1_order_batch_orders = spotPrivatePostV1OrderBatchOrders = Entry('v1/order/batch-orders', ['spot', 'private'], 'POST', {'cost': 0.4})
+    spot_private_post_v1_order_auto_place = spotPrivatePostV1OrderAutoPlace = Entry('v1/order/auto/place', ['spot', 'private'], 'POST', {'cost': 0.2})
     spot_private_post_v1_order_orders_order_id_submitcancel = spotPrivatePostV1OrderOrdersOrderIdSubmitcancel = Entry('v1/order/orders/{order-id}/submitcancel', ['spot', 'private'], 'POST', {'cost': 0.2})
     spot_private_post_v1_order_orders_submitcancelclientorder = spotPrivatePostV1OrderOrdersSubmitCancelClientOrder = Entry('v1/order/orders/submitCancelClientOrder', ['spot', 'private'], 'POST', {'cost': 0.2})
     spot_private_post_v1_order_orders_batchcancelopenorders = spotPrivatePostV1OrderOrdersBatchCancelOpenOrders = Entry('v1/order/orders/batchCancelOpenOrders', ['spot', 'private'], 'POST', {'cost': 0.4})
@@ -315,8 +316,12 @@ class ImplicitAPI:
     contract_private_get_api_v1_contract_api_trading_status = contractPrivateGetApiV1ContractApiTradingStatus = Entry('api/v1/contract_api_trading_status', ['contract', 'private'], 'GET', {'cost': 1})
     contract_private_get_swap_api_v1_swap_api_trading_status = contractPrivateGetSwapApiV1SwapApiTradingStatus = Entry('swap-api/v1/swap_api_trading_status', ['contract', 'private'], 'GET', {'cost': 1})
     contract_private_get_linear_swap_api_v1_swap_api_trading_status = contractPrivateGetLinearSwapApiV1SwapApiTradingStatus = Entry('linear-swap-api/v1/swap_api_trading_status', ['contract', 'private'], 'GET', {'cost': 1})
+    contract_private_get_linear_swap_api_v1_swap_cross_position_side = contractPrivateGetLinearSwapApiV1SwapCrossPositionSide = Entry('linear-swap-api/v1/swap_cross_position_side', ['contract', 'private'], 'GET', {'cost': 1})
+    contract_private_get_linear_swap_api_v1_swap_position_side = contractPrivateGetLinearSwapApiV1SwapPositionSide = Entry('linear-swap-api/v1/swap_position_side', ['contract', 'private'], 'GET', {'cost': 1})
     contract_private_get_linear_swap_api_v3_unified_account_info = contractPrivateGetLinearSwapApiV3UnifiedAccountInfo = Entry('linear-swap-api/v3/unified_account_info', ['contract', 'private'], 'GET', {'cost': 1})
+    contract_private_get_linear_swap_api_v3_fix_position_margin_change_record = contractPrivateGetLinearSwapApiV3FixPositionMarginChangeRecord = Entry('linear-swap-api/v3/fix_position_margin_change_record', ['contract', 'private'], 'GET', {'cost': 1})
     contract_private_get_linear_swap_api_v3_swap_unified_account_type = contractPrivateGetLinearSwapApiV3SwapUnifiedAccountType = Entry('linear-swap-api/v3/swap_unified_account_type', ['contract', 'private'], 'GET', {'cost': 1})
+    contract_private_get_linear_swap_api_v3_linear_swap_overview_account_info = contractPrivateGetLinearSwapApiV3LinearSwapOverviewAccountInfo = Entry('linear-swap-api/v3/linear_swap_overview_account_info', ['contract', 'private'], 'GET', {'cost': 1})
     contract_private_post_api_v1_contract_balance_valuation = contractPrivatePostApiV1ContractBalanceValuation = Entry('api/v1/contract_balance_valuation', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_api_v1_contract_account_info = contractPrivatePostApiV1ContractAccountInfo = Entry('api/v1/contract_account_info', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_api_v1_contract_position_info = contractPrivatePostApiV1ContractPositionInfo = Entry('api/v1/contract_position_info', ['contract', 'private'], 'POST', {'cost': 1})
@@ -338,6 +343,7 @@ class ImplicitAPI:
     contract_private_post_api_v1_contract_available_level_rate = contractPrivatePostApiV1ContractAvailableLevelRate = Entry('api/v1/contract_available_level_rate', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_api_v3_contract_financial_record = contractPrivatePostApiV3ContractFinancialRecord = Entry('api/v3/contract_financial_record', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_api_v3_contract_financial_record_exact = contractPrivatePostApiV3ContractFinancialRecordExact = Entry('api/v3/contract_financial_record_exact', ['contract', 'private'], 'POST', {'cost': 1})
+    contract_private_post_api_v1_contract_cancel_after = contractPrivatePostApiV1ContractCancelAfter = Entry('api/v1/contract-cancel-after', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_api_v1_contract_order = contractPrivatePostApiV1ContractOrder = Entry('api/v1/contract_order', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_v1_contract_batchorder = contractPrivatePostV1ContractBatchorder = Entry('v1/contract_batchorder', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_api_v1_contract_cancel = contractPrivatePostApiV1ContractCancel = Entry('api/v1/contract_cancel', ['contract', 'private'], 'POST', {'cost': 1})
@@ -392,6 +398,7 @@ class ImplicitAPI:
     contract_private_post_swap_api_v1_swap_master_sub_transfer_record = contractPrivatePostSwapApiV1SwapMasterSubTransferRecord = Entry('swap-api/v1/swap_master_sub_transfer_record', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_swap_api_v3_swap_financial_record = contractPrivatePostSwapApiV3SwapFinancialRecord = Entry('swap-api/v3/swap_financial_record', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_swap_api_v3_swap_financial_record_exact = contractPrivatePostSwapApiV3SwapFinancialRecordExact = Entry('swap-api/v3/swap_financial_record_exact', ['contract', 'private'], 'POST', {'cost': 1})
+    contract_private_post_swap_api_v1_swap_cancel_after = contractPrivatePostSwapApiV1SwapCancelAfter = Entry('swap-api/v1/swap-cancel-after', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_swap_api_v1_swap_order = contractPrivatePostSwapApiV1SwapOrder = Entry('swap-api/v1/swap_order', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_swap_api_v1_swap_batchorder = contractPrivatePostSwapApiV1SwapBatchorder = Entry('swap-api/v1/swap_batchorder', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_swap_api_v1_swap_cancel = contractPrivatePostSwapApiV1SwapCancel = Entry('swap-api/v1/swap_cancel', ['contract', 'private'], 'POST', {'cost': 1})
@@ -486,6 +493,7 @@ class ImplicitAPI:
     contract_private_post_linear_swap_api_v1_swap_cross_matchresults = contractPrivatePostLinearSwapApiV1SwapCrossMatchresults = Entry('linear-swap-api/v1/swap_cross_matchresults', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_matchresults_exact = contractPrivatePostLinearSwapApiV1SwapMatchresultsExact = Entry('linear-swap-api/v1/swap_matchresults_exact', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_cross_matchresults_exact = contractPrivatePostLinearSwapApiV1SwapCrossMatchresultsExact = Entry('linear-swap-api/v1/swap_cross_matchresults_exact', ['contract', 'private'], 'POST', {'cost': 1})
+    contract_private_post_linear_swap_api_v1_linear_cancel_after = contractPrivatePostLinearSwapApiV1LinearCancelAfter = Entry('linear-swap-api/v1/linear-cancel-after', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_switch_position_mode = contractPrivatePostLinearSwapApiV1SwapSwitchPositionMode = Entry('linear-swap-api/v1/swap_switch_position_mode', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_cross_switch_position_mode = contractPrivatePostLinearSwapApiV1SwapCrossSwitchPositionMode = Entry('linear-swap-api/v1/swap_cross_switch_position_mode', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v3_swap_matchresults = contractPrivatePostLinearSwapApiV3SwapMatchresults = Entry('linear-swap-api/v3/swap_matchresults', ['contract', 'private'], 'POST', {'cost': 1})
@@ -496,7 +504,9 @@ class ImplicitAPI:
     contract_private_post_linear_swap_api_v3_swap_cross_hisorders = contractPrivatePostLinearSwapApiV3SwapCrossHisorders = Entry('linear-swap-api/v3/swap_cross_hisorders', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v3_swap_hisorders_exact = contractPrivatePostLinearSwapApiV3SwapHisordersExact = Entry('linear-swap-api/v3/swap_hisorders_exact', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v3_swap_cross_hisorders_exact = contractPrivatePostLinearSwapApiV3SwapCrossHisordersExact = Entry('linear-swap-api/v3/swap_cross_hisorders_exact', ['contract', 'private'], 'POST', {'cost': 1})
+    contract_private_post_linear_swap_api_v3_fix_position_margin_change = contractPrivatePostLinearSwapApiV3FixPositionMarginChange = Entry('linear-swap-api/v3/fix_position_margin_change', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v3_swap_switch_account_type = contractPrivatePostLinearSwapApiV3SwapSwitchAccountType = Entry('linear-swap-api/v3/swap_switch_account_type', ['contract', 'private'], 'POST', {'cost': 1})
+    contract_private_post_linear_swap_api_v3_linear_swap_fee_switch = contractPrivatePostLinearSwapApiV3LinearSwapFeeSwitch = Entry('linear-swap-api/v3/linear_swap_fee_switch', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_trigger_order = contractPrivatePostLinearSwapApiV1SwapTriggerOrder = Entry('linear-swap-api/v1/swap_trigger_order', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_cross_trigger_order = contractPrivatePostLinearSwapApiV1SwapCrossTriggerOrder = Entry('linear-swap-api/v1/swap_cross_trigger_order', ['contract', 'private'], 'POST', {'cost': 1})
     contract_private_post_linear_swap_api_v1_swap_trigger_cancel = contractPrivatePostLinearSwapApiV1SwapTriggerCancel = Entry('linear-swap-api/v1/swap_trigger_cancel', ['contract', 'private'], 'POST', {'cost': 1})
