@@ -6,7 +6,7 @@ import json
 import os
 import sys
 import time  # noqa: F401
-from traceback import format_tb
+from traceback import format_tb, format_exception
 
 import importlib  # noqa: E402
 import glob  # noqa: E402
@@ -69,7 +69,7 @@ Error = Exception
 
 
 def handle_all_unhandled_exceptions(type, value, traceback):
-    dump((type), (value), '\n\n' + ('\n'.join(format_tb(traceback))))
+    dump((type), (value), '\n<UNHANDLED EXCEPTION>\n' + ('\n'.join(format_tb(traceback))))
     exit(1)  # unrecoverable crash
 
 
@@ -129,7 +129,11 @@ def call_method(testFiles, methodName, exchange, skippedProperties, args):
 
 
 def exception_message(exc):
-    return '[' + type(exc).__name__ + '] ' + str(exc)[0:500]
+    message = '[' + type(exc).__name__ + '] ' + "".join(format_exception(type(exc), exc, exc.__traceback__, limit=6))
+    if len(message) > 1000:
+        # Accessing out of range element causes error
+        message = message[0:1000]
+    return message
 
 
 def exit_script():
@@ -178,7 +182,6 @@ def close(exchange):
 from ccxt.base.errors import NetworkError
 from ccxt.base.errors import DDoSProtection
 from ccxt.base.errors import RateLimitExceeded
-from ccxt.base.errors import ExchangeNotAvailable
 from ccxt.base.errors import OnMaintenance
 from ccxt.base.errors import RequestTimeout
 from ccxt.base.errors import AuthenticationError
@@ -197,7 +200,7 @@ class testMainClass(baseMainTestClass):
     def init(self, exchangeId, symbol):
         self.parse_cli_args()
         symbolStr = symbol is not symbol if None else 'all'
-        print('\nTESTING ', ext, {'exchange': exchangeId, 'symbol': symbolStr}, '\n')
+        dump('\nTESTING ', ext, {'exchange': exchangeId, 'symbol': symbolStr}, '\n')
         exchangeArgs = {
             'verbose': self.verbose,
             'debug': self.debug,
@@ -208,7 +211,6 @@ class testMainClass(baseMainTestClass):
         self.import_files(exchange)
         self.expand_settings(exchange, symbol)
         self.start_test(exchange, symbol)
-        close(exchange)
 
     def import_files(self, exchange):
         # exchange tests
@@ -279,36 +281,27 @@ class testMainClass(baseMainTestClass):
         if not isPublic and (methodNameInTest in self.checkedPublicTests) and (methodName != 'fetchCurrencies'):
             return
         skipMessage = None
-        isFetchOhlcvEmulated = (methodName == 'fetchOHLCV' and exchange.has['fetchOHLCV'] == 'emulated')  # todo: remove emulation from base
-        if not isLoadMarkets and (not(methodName in exchange.has) or not exchange.has[methodName]) or isFetchOhlcvEmulated:
+        if not isLoadMarkets and (not(methodName in exchange.has) or not exchange.has[methodName]):
             skipMessage = '[INFO:UNSUPPORTED_TEST]'  # keep it aligned with the longest message
         elif (methodName in self.skippedMethods) and (isinstance(self.skippedMethods[methodName], str)):
             skipMessage = '[INFO:SKIPPED_TEST]'
         elif not (methodNameInTest in self.testFiles):
             skipMessage = '[INFO:UNIMPLEMENTED_TEST]'
-        argsStringified = '(' + ','.join(args) + ')'
-        try:
-            # exceptionally for `loadMarkets` call, we call it before it's even checked for "skip" need it to be called anyway(but can skip "test.loadMarket" for it)
-            if isLoadMarkets:
-                exchange.load_markets()
-            if skipMessage:
-                if self.info:
-                    dump(self.add_padding(skipMessage, 25), exchange.id, methodNameInTest)
-                return
+        # exceptionally for `loadMarkets` call, we call it before it's even checked for "skip" need it to be called anyway(but can skip "test.loadMarket" for it)
+        if isLoadMarkets:
+            exchange.load_markets(True)
+        if skipMessage:
             if self.info:
-                dump(self.add_padding('[INFO:TESTING]', 25), exchange.id, methodNameInTest, argsStringified)
-            skippedProperties = exchange.safe_value(self.skippedMethods, methodName, {})
-            call_method(self.testFiles, methodNameInTest, exchange, skippedProperties, args)
-            if isPublic:
-                self.checkedPublicTests[methodNameInTest] = True
-        except Exception as e:
-            isAuthError = (isinstance(e, AuthenticationError))
-            # If public test faces authentication error, we don't break(see comments under `testSafe` method)
-            if isPublic and isAuthError:
-                if self.info:
-                    dump('[TEST_WARNING]', 'Authentication problem for public method', exception_message(e), exchange.id, methodNameInTest, argsStringified)
-            else:
-                raise e
+                dump(self.add_padding(skipMessage, 25), exchange.id, methodNameInTest)
+            return
+        if self.info:
+            argsStringified = '(' + ','.join(args) + ')'
+            dump(self.add_padding('[INFO:TESTING]', 25), exchange.id, methodNameInTest, argsStringified)
+        skippedProperties = exchange.safe_value(self.skippedMethods, methodName, {})
+        call_method(self.testFiles, methodNameInTest, exchange, skippedProperties, args)
+        # if it was passed successfully, add to the list of successfull tests
+        if isPublic:
+            self.checkedPublicTests[methodNameInTest] = True
 
     def test_safe(self, methodName, exchange, args=[], isPublic=False):
         # `testSafe` method does not raise an exception, instead mutes it.
@@ -328,31 +321,34 @@ class testMainClass(baseMainTestClass):
                 self.test_method(methodName, exchange, args, isPublic)
                 return True
             except Exception as e:
+                isAuthError = (isinstance(e, AuthenticationError))
                 isRateLimitExceeded = (isinstance(e, RateLimitExceeded))
-                isExchangeNotAvailable = (isinstance(e, ExchangeNotAvailable))
                 isNetworkError = (isinstance(e, NetworkError))
                 isDDoSProtection = (isinstance(e, DDoSProtection))
                 isRequestTimeout = (isinstance(e, RequestTimeout))
-                tempFailure = (isRateLimitExceeded or isExchangeNotAvailable or isNetworkError or isDDoSProtection or isRequestTimeout)
+                tempFailure = (isRateLimitExceeded or isNetworkError or isDDoSProtection or isRequestTimeout)
                 if tempFailure:
-                    # wait and retry again
-                    exchange.sleep(i * 1000)  # increase wait seconds on every retry
                     # if last retry was gone with same `tempFailure` error, then let's eventually return False
                     if i == maxRetries - 1:
                         dump('[TEST_WARNING]', 'Method could not be tested due to a repeated Network/Availability issues', ' | ', exchange.id, methodName, argsStringified)
-                        if methodName == 'loadMarkets':
-                            # in case of loadMarkets, we completely stop test for current exchange
-                            exit_script()
-                        return False
-                    continue
+                    else:
+                        # wait and retry again
+                        exchange.sleep(i * 1000)  # increase wait seconds on every retry
+                        continue
                 elif isinstance(e, OnMaintenance):
                     # in case of maintenance, skip exchange(don't fail the test)
                     dump('[TEST_WARNING] Exchange is on maintenance', exchange.id)
-                    exit_script()
+                # If public test faces authentication error, we don't break(see comments under `testSafe` method)
+                elif isPublic and isAuthError:
+                    # in case of loadMarkets, it means that "tester"(developer or travis) does not have correct authentication, so it does not have a point to proceed at all
+                    if methodName == 'loadMarkets':
+                        dump('[TEST_WARNING]', 'Exchange can not be tested, because of authentication problems during loadMarkets', exception_message(e), exchange.id, methodName, argsStringified)
+                    if self.info:
+                        dump('[TEST_WARNING]', 'Authentication problem for public method', exception_message(e), exchange.id, methodName, argsStringified)
                 else:
                     # if not a temporary connectivity issue, then mark test(no need to re-try)
                     dump('[TEST_FAILURE]', exception_message(e), exchange.id, methodName, argsStringified)
-                    return False
+                return False
 
     def run_public_tests(self, exchange, symbol):
         tests = {
@@ -397,12 +393,15 @@ class testMainClass(baseMainTestClass):
                     errors.append(testNames[i])
             # we don't raise exception for public-tests, see comments under 'testSafe' method
             failedMsg = ''
-            if len(errors):
-                failedMsg = ' | Failed methods: ' + ', '.join(errors)
+            errorsLength = len(errors)
+            if errorsLength > 0:
+                failedMsg = ' | Failed methods : ' + ', '.join(errors)
             dump(self.add_padding('[INFO:PUBLIC_TESTS_END] ' + market['type'] + failedMsg, 25), exchange.id)
 
     def load_exchange(self, exchange):
-        self.test_safe('loadMarkets', exchange, [], True)
+        result = self.test_safe('loadMarkets', exchange, [], True)
+        if not result:
+            return False
         symbols = [
             'BTC/CNY',
             'BTC/USD',
@@ -441,6 +440,7 @@ class testMainClass(baseMainTestClass):
             else:
                 resultMsg = ', '.join(resultSymbols)
         dump('Exchange loaded', exchangeSymbolsLength, 'symbols', resultMsg)
+        return True
 
     def get_test_symbol(self, exchange, isSpot, symbols):
         symbol = None
@@ -623,7 +623,7 @@ class testMainClass(baseMainTestClass):
             'fetchOpenOrders': [symbol],
             'fetchClosedOrders': [symbol],
             'fetchMyTrades': [symbol],
-            'fetchLeverageTiers': [symbol],
+            'fetchLeverageTiers': [[symbol]],
             'fetchLedger': [code],
             'fetchTransactions': [code],
             'fetchDeposits': [code],
@@ -631,32 +631,32 @@ class testMainClass(baseMainTestClass):
             'fetchBorrowRates': [code],
             'fetchBorrowRate': [code],
             'fetchBorrowInterest': [code, symbol],
-            'addMargin': [symbol],
-            'reduceMargin': [symbol],
-            'setMargin': [symbol],
-            'setMarginMode': [symbol],
-            'setLeverage': [symbol],
+            # 'addMargin': [],
+            # 'reduceMargin': [],
+            # 'setMargin': [],
+            # 'setMarginMode': [],
+            # 'setLeverage': [],
             'cancelAllOrders': [symbol],
-            'cancelOrder': [symbol],
-            'cancelOrders': [symbol],
+            # 'cancelOrder': [],
+            # 'cancelOrders': [],
             'fetchCanceledOrders': [symbol],
-            'fetchClosedOrder': [symbol],
-            'fetchOpenOrder': [symbol],
-            'fetchOrder': [symbol],
-            'fetchOrderTrades': [symbol],
+            # 'fetchClosedOrder': [],
+            # 'fetchOpenOrder': [],
+            # 'fetchOrder': [],
+            # 'fetchOrderTrades': [],
             'fetchPosition': [symbol],
             'fetchDeposit': [code],
             'createDepositAddress': [code],
             'fetchDepositAddress': [code],
             'fetchDepositAddresses': [code],
             'fetchDepositAddressesByNetwork': [code],
-            'editOrder': [symbol],
-            'fetchBorrowRateHistory': [symbol],
-            'fetchBorrowRatesPerSymbol': [symbol],
+            # 'editOrder': [],
+            'fetchBorrowRateHistory': [code],
+            'fetchBorrowRatesPerSymbol': [],
             'fetchLedgerEntry': [code],
-            'fetchWithdrawal': [code],
-            'transfer': [code],
-            'withdraw': [code],
+            # 'fetchWithdrawal': [],
+            # 'transfer': [],
+            # 'withdraw': [],
         }
         market = exchange.market(symbol)
         isSpot = market['spot']
@@ -694,13 +694,22 @@ class testMainClass(baseMainTestClass):
                 dump(self.add_padding('[INFO:PRIVATE_TESTS_DONE]', 25), exchange.id)
 
     def start_test(self, exchange, symbol):
-        # we don't need to test aliases
+        # we do not need to test aliases
         if exchange.alias:
             return
         if self.sandbox or get_exchange_prop(exchange, 'sandbox'):
             exchange.set_sandbox_mode(True)
-        self.load_exchange(exchange)
-        self.test_exchange(exchange, symbol)
+        # because of python-async, we need proper `.close()` handling
+        try:
+            result = self.load_exchange(exchange)
+            if not result:
+                close(exchange)
+                return
+            self.test_exchange(exchange, symbol)
+            close(exchange)
+        except Exception as e:
+            close(exchange)
+            raise e
 
 # ***** AUTO-TRANSPILER-END *****
 # *******************************
